import {
  Http, IDictionary, Metadata,
} from '@zeedhi/core';
import {
  Date as ZdDate, Form, LoadingService, Button, Text as ZdText, TextInput as ZdTextInput,
} from '@zeedhi/common';
import {
  Utilities,
 } from '@/util/Utilities';

export class CentroCustoRelatorioController {
    public gridVisivel : boolean = true;

    public currentRow : any = {};

    get formVisivel() {
        return !this.gridVisivel;
    }

    public openPreview({ row }: any) {
        this.gridVisivel = false;
        this.currentRow = row;
        this.montasAbaDetalhes();
    }

    public voltarGrid() {
        this.gridVisivel = true;
    }

    public montasAbaDetalhes() {
        const DTAPROVACAO = new Date(this.currentRow.DTAPROVACAO).toLocaleString();
        const DTACEITEORCA = new Date(this.currentRow.DTACEITEORCA).toLocaleString();
        Metadata.getInstance<ZdTextInput>('NRCONTRATOFCT').value = this.currentRow.NRCONTRATOFCT;
        Metadata.getInstance<ZdTextInput>('NMMODCONTRATO').value = this.currentRow.NMMODCONTRATO;
        Metadata.getInstance<ZdDate>('DTAPROVACAO').value = DTAPROVACAO;
        Metadata.getInstance<ZdTextInput>('NMTIPOORCAMENTO').value = this.currentRow.NMTIPOORCAMENTO;
        Metadata.getInstance<ZdTextInput>('NMPRINCIPALPARC').value = this.currentRow.NMPRINCIPALPARC;
        Metadata.getInstance<ZdTextInput>('NMSECUNDARIPARC').value = this.currentRow.NMSECUNDARIPARC;
        Metadata.getInstance<ZdTextInput>('NRINSCRICAOPARC').value = this.currentRow.NRINSCRICAOPARC;
        Metadata.getInstance<ZdTextInput>('NMOPERADOR').value = this.currentRow.NMOPERADOR;
        Metadata.getInstance<ZdTextInput>('NRORCAMENTO').value = this.currentRow.NRORCAMENTO;
        Metadata.getInstance<ZdTextInput>('NMORCAMENTOMODELO').value = this.currentRow.NMORCAMENTOMODELO;
        Metadata.getInstance<ZdDate>('DTACEITEORCA').value = DTACEITEORCA;
        Metadata.getInstance<ZdTextInput>('NMCENTCUST').value = this.currentRow.NMCENTCUST;
        Metadata.getInstance<ZdTextInput>('NMSERVORCA').value = this.currentRow.NMSERVORCA;
        Metadata.getInstance<ZdTextInput>('NMITEMCONTRATO').value = this.currentRow.NMITEMCONTRATO;
        Metadata.getInstance<ZdTextInput>('DSTPMEDIDAVARIAVEL').value = this.currentRow.DSTPMEDIDAVARIAVEL;
        Metadata.getInstance<ZdTextInput>('QTMEDIDAVARIAVEL').value = this.currentRow.QTMEDIDAVARIAVEL;
        Metadata.getInstance<ZdTextInput>('VRTOTAL_ACR_DESC').value = this.currentRow.VRTOTAL_ACR_DESC;
    }

    public openFilter({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public atualizarGrid() {
        const filterButton = Metadata.getInstance<Button>('basic-tek-grid_refreshButton');
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public expandir({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;
        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public atualizarView(atualizarGrid = true) {
        LoadingService.show('Atualizando dados do relatório...');
        Http.post('/atualizarView').then(() => {
            this.buscarDataHoraUltimaAtualizacaoView();
            if (atualizarGrid) {
                this.atualizarGrid();
            }
        LoadingService.hide();
        }).catch((error: any) => {
            LoadingService.hide();
            Utilities.showErrorMessage(error);
        });
    }

    public buscarDataHoraUltimaAtualizacaoView() {
        Http.post('/getDataUltimaAtualizacaoRelatorioCentroCusto').then((response: IDictionary) => {
            const { data } = response;

            if (data) {
                this.atualizarLabelContainerDataAtualizacao(data);
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        });
    }

    public atualizarLabelContainerDataAtualizacao(data : any) {
        const dataAtual = new Date().toLocaleDateString();
        if (dataAtual !== data.split(' ')[0]) {
            this.atualizarView(false);
        }
        Metadata.getInstance<ZdText>('ultimaAtualizacao').text = `(Atualizado em ${data})`;
    }
}
